# wrap.tcl --
#
# Initialization script normally executed in the interpreter for each
# Wrap-based application.
#
# Copyright (c) 1999  Jan Nijtmans
#
# See the file "license.terms" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

# Insist on running with compatible version of Tcl.

package require Tcl 8.2

# Add Wrap's directory to the end of the auto-load search path, if it
# isn't already on the path:

if {[info exists auto_path] && [string compare $::wrap::library {}] &&
	[lsearch -exact $auto_path $::wrap::library] < 0} {
    lappend auto_path $::wrap::library
}

#
# Find out where temporary files can be stored.
#

namespace eval wrap {
    variable temp

    set temp [::file nativename /tmp]
    catch {set temp $env(TMP)}
    catch {set temp $env(TEMP)}
    regsub -all {\\} $temp "/" temp
    if {![::file isdirectory $temp]} {
	set temp /temp
	if {![::file isdirectory $temp]} {
	    set temp [::file dirname [::info nameofexecutable]]
	}
    }
}

#
# Index file processing. Works for both pkgIndex.tcl and tclIndex files
#

proc ::wrap::index path {
    set f [::wrap::open $path]
    set code [read $f]
    close $f
    regsub -all {source} $code {::wrap::source} code
    regsub -all {load} $code {::wrap::load} code
    uplevel [list set dir [file dirname $path]]
    uplevel [list eval $code]
}

#
# binary package processing.
#

proc ::wrap::load {path pkg} {
    if {![catch [list uplevel #0 ::load {} $pkg]]} {
	return
    }
    set f [::wrap::open $path]
    set g [::open [set fileName [file join ${::wrap::temp} [file tail $path]]] w]
    fconfigure $f -translation binary -encoding binary
    fconfigure $g -translation binary -encoding binary
    fcopy $f $g
    close $f
    close $g
    uplevel #0 ::load $fileName $pkg
}
